pub struct AliasGenerator { /* private fields */ }Expand description
A utility struct that can be used to generate unique aliases when optimizing queries
Implementations
Sourceimpl AliasGenerator
impl AliasGenerator
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new AliasGenerator
Sourcepub fn update_min_id(&self, min_id: usize)
pub fn update_min_id(&self, min_id: usize)
Advance the counter to at least min_id, ensuring future aliases
won’t collide with already-existing ones.
For example, if the query already contains an alias alias_42, then calling
update_min_id(42) will ensure that future aliases generated by this
AliasGenerator will start from alias_43.