pub struct FormatOptions {
pub safe: bool,
pub null: String,
pub date_format: Option<String>,
pub datetime_format: Option<String>,
pub timestamp_format: Option<String>,
pub timestamp_tz_format: Option<String>,
pub time_format: Option<String>,
pub duration_format: String,
pub types_info: bool,
}Expand description
Options controlling the format of output when printing record batches
Copies arrow::util::display::FormatOptions
Fields
safe: boolIf set to true any formatting errors will be written to the output
instead of being converted into a std::fmt::Error
null: StringFormat string for nulls
date_format: Option<String>Date format for date arrays
datetime_format: Option<String>Format for DateTime arrays
timestamp_format: Option<String>Timestamp format for timestamp arrays
timestamp_tz_format: Option<String>Timestamp format for timestamp with timezone arrays. When None, ISO 8601 format is used.
time_format: Option<String>Time format for time arrays
duration_format: StringDuration format. Can be either "pretty" or "ISO8601"
types_info: boolShow types in visual representation batches