pub trait ConfigField {
// Required methods
fn visit<V: Visit>(&self, v: &mut V, key: &str, description: &'static str);
fn set(&mut self, key: &str, value: &str) -> Result<()>;
// Provided method
fn reset(&mut self, key: &str) -> Result<()> { ... }
}Expand description
A trait implemented by config_namespace and for field types that provides
the ability to walk and mutate the configuration tree
Required Methods
fn visit<V: Visit>(&self, v: &mut V, key: &str, description: &'static str)
fn set(&mut self, key: &str, value: &str) -> Result<()>
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl ConfigField for HashMap<String, ParquetColumnOptions>
impl ConfigField for HashMap<String, ParquetColumnOptions>
Sourceimpl ConfigField for Option<MaxRowGroupBytes>
ConfigField for Option<MaxRowGroupBytes>. A custom impl (rather than the
blanket Option<F> one) so an invalid value is rejected without leaving the
option in an invalid intermediate state on error. MaxRowGroupBytes
deliberately does not implement Default, so the blanket impl does not apply.
impl ConfigField for Option<MaxRowGroupBytes>
ConfigField for Option<MaxRowGroupBytes>. A custom impl (rather than the
blanket Option<F> one) so an invalid value is rejected without leaving the
option in an invalid intermediate state on error. MaxRowGroupBytes
deliberately does not implement Default, so the blanket impl does not apply.