pub trait Normalizeable {
// Required method
fn can_normalize(&self) -> bool;
}Expand description
The Normalizeable trait defines a method to determine whether a node can be normalized.
Normalization is the process of converting a node into a canonical form that can be used
to compare nodes for equality. This is useful in optimizations like Common Subexpression Elimination (CSE),
where semantically equivalent nodes (e.g., a + b and b + a) should be treated as equal.
Required Methods
fn can_normalize(&self) -> bool
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".