pub enum Constraint {
PrimaryKey(Vec<usize>),
Unique(Vec<usize>),
}Expand description
This object defines a constraint on a table.
Variants
PrimaryKey(Vec<usize>)
Columns with the given indices form a composite primary key (they are jointly unique and not nullable):
Unique(Vec<usize>)
Columns with the given indices form a composite unique key: