TableReference

Enum TableReference 

pub enum TableReference {
    Bare {
        table: Arc<str>,
    },
    Partial {
        schema: Arc<str>,
        table: Arc<str>,
    },
    Full {
        catalog: Arc<str>,
        schema: Arc<str>,
        table: Arc<str>,
    },
}
A multi part identifier (path) to a table that may require further resolution (e.g. foo.bar).

TableReferences are cheap to clone() as they are implemented with Arc.

See ResolvedTableReference for a fully resolved table reference.

Creating TableReference

When converting strings to TableReferences, the string is parsed as though it were a SQL identifier, normalizing (convert to lowercase) any unquoted identifiers. TableReference::bare creates references without applying normalization semantics.

Examples

// Get a table reference to 'mytable'
let table_reference = TableReference::from("mytable");
assert_eq!(table_reference, TableReference::bare("mytable"));

// Get a table reference to 'mytable' (note the capitalization)
let table_reference = TableReference::from("MyTable");
assert_eq!(table_reference, TableReference::bare("mytable"));

// Get a table reference to 'MyTable' (note the capitalization) using double quotes
// (programmatically it is better to use `TableReference::bare` for this)
let table_reference = TableReference::from(r#""MyTable""#);
assert_eq!(table_reference, TableReference::bare("MyTable"));

// Get a table reference to 'myschema.mytable' (note the capitalization)
let table_reference = TableReference::from("MySchema.MyTable");
assert_eq!(
    table_reference,
    TableReference::partial("myschema", "mytable")
);

Variants



Bare

An unqualified table reference, e.g. “table”

Fields

table: Arc<str>

The table name



Partial

A partially resolved table reference, e.g. “schema.table”

Fields

schema: Arc<str>

The schema containing the table

table: Arc<str>

The table name



Full

A fully resolved table reference, e.g. “catalog.schema.table”

Fields

catalog: Arc<str>

The catalog (aka database) containing the table

schema: Arc<str>

The schema containing the table

table: Arc<str>

The table name

Implementations

Source

impl TableReference

pub fn none() -> Option<TableReference>

Convenience method for creating a typed none None

pub fn bare(table: impl Into<Arc<str>>) -> TableReference

Convenience method for creating a TableReference::Bare

As described on TableReference this does NO normalization at all, so “Foo.Bar” stays as a reference to the table named “Foo.Bar” (rather than “foo”.“bar”)

pub fn partial( schema: impl Into<Arc<str>>, table: impl Into<Arc<str>>, ) -> TableReference

Convenience method for creating a TableReference::Partial.

Note: NO normalization is applied to the schema or table name.

pub fn full( catalog: impl Into<Arc<str>>, schema: impl Into<Arc<str>>, table: impl Into<Arc<str>>, ) -> TableReference

Convenience method for creating a TableReference::Full

Note: NO normalization is applied to the catalog, schema or table name.

pub fn table(&self) -> &str

Retrieve the table name, regardless of qualification.

pub fn schema(&self) -> Option<&str>

Retrieve the schema name if [Self::Partial] or [Self::Full], None` otherwise.

pub fn catalog(&self) -> Option<&str>

Retrieve the catalog name if Self::Full, None otherwise.

pub fn resolved_eq(&self, other: &Self) -> bool

Compare with another TableReference as if both are resolved. This allows comparing across variants. If a field is not present in both variants being compared then it is ignored in the comparison.

e.g. this allows a TableReference::Bare to be considered equal to a fully qualified TableReference::Full if the table names match.

pub fn resolve( self, default_catalog: &str, default_schema: &str, ) -> ResolvedTableReference

Given a default catalog and schema, ensure this table reference is fully resolved

pub fn to_quoted_string(&self) -> String

Forms a string where the identifiers are quoted

Example
let table_reference = TableReference::partial("myschema", "mytable");
assert_eq!(table_reference.to_quoted_string(), "myschema.mytable");

let table_reference = TableReference::partial("MySchema", "MyTable");
assert_eq!(
    table_reference.to_quoted_string(),
    r#""MySchema"."MyTable""#
);
pub fn parse_str(s: &str) -> Self

Forms a TableReference by parsing s as a multipart SQL identifier, normalizing s to lowercase. See docs on TableReference for more details.

pub fn parse_str_normalized(s: &str, ignore_case: bool) -> Self

Forms a TableReference by parsing s as a multipart SQL identifier, normalizing s to lowercase if ignore_case is false. See docs on TableReference for more details.

pub fn to_vec(&self) -> Vec<String>

Decompose a TableReference to separate parts. The result vector contains at most three elements in the following sequence:

[<catalog>, <schema>, table]