Module hash_utils

Module hash_utils 

Functionality used both on logical and physical plans

Constants

HLL_RANDOM_STATE
Fixed quality hash state used by HyperLogLog sketches.

Traits

AsDynArray
Something that can be returned as a &dyn Array.
HashState
Hash state used by create_hashes.
HashValue

Functions

combine_hashes
create_hashes
Creates hash values for every row, based on the values in the columns.
create_hashes_with_hasher
Creates hash values for every row using a caller-provided hash builder.
with_hashes
Creates hashes for the given arrays using a thread-local buffer, then calls the provided callback with an immutable reference to the computed hashes.
with_hashes_with_hasher
Creates hashes for the given arrays using a thread-local buffer and a custom hash builder, then calls the provided callback with the computed hashes.

Type Aliases

QualityRandomState
RandomState
RandomState is optimized for speed and suitable for hash tables and bloom filters. QualityRandomState is optimized for statistical quality and suitable for algorithms such as HyperLogLog. The tradeoff is that the fast variant gives up some statistical quality, while the quality variant is slightly slower.