HashState

Trait HashState 

pub trait HashState: BuildHasher {
    type SeededState: BuildHasher;

    // Required method
    fn seeded_state(&self, seed: u64) -> Self::SeededState;
}
Hash state used by create_hashes.

Multi-column hashing folds the previous column hash into a fresh hasher before hashing the next column. This trait keeps that seeded hasher in the same foldhash tier as the top-level hash state.

Required Associated Types

Required Methods

fn seeded_state(&self, seed: u64) -> Self::SeededState

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl HashState for FixedState

Source

impl HashState for FixedState

Implementors