RandomState

Type Alias RandomState 

pub type RandomState = FixedState;
RandomState is optimized for speed and suitable for hash tables and bloom filters. QualityRandomState is optimized for statistical quality and suitable for algorithms such as HyperLogLog. The tradeoff is that the fast variant gives up some statistical quality, while the quality variant is slightly slower.

See: https://docs.rs/foldhash/0.2.0/src/foldhash/lib.rs.html#17-21

Aliased Type

pub struct RandomState { /* private fields */ }