Module stats

Module stats 

This module provides data structures to represent statistics

Structs

ColumnStatistics
Statistics for a column within a relation
Statistics
Statistics for a relation Fields are optional and can be inexact because the sources sometimes provide approximate estimates for performance reasons and the transformations output are not always predictable.

Enums

NdvFallback
Fallback to use when NDV overlap can not be estimated from column bounds.
Precision
Represents a value with a degree of certainty. Precision is used to propagate information the precision of statistical values.

Functions

estimate_ndv_with_overlap
Estimates the combined number of distinct values (NDV) when merging two column statistics, using range overlap to avoid double-counting shared values.