pub enum NdvFallback {
Max,
Sum,
}Expand description
Fallback to use when NDV overlap can not be estimated from column bounds.
Variants
Max
Use the larger input NDV. This is the conservative default for related fragments such as files from the same table.
Sum
Sum the input NDVs. This is a conservative upper bound for
independent inputs such as UNION ALL.