pub struct RecursionUnnestOption {
pub input_column: Column,
pub output_column: Column,
pub depth: usize,
}Expand description
Instruction on how to unnest a column (mostly with a list type) such as how to name the output, and how many level it should be unnested
Fields
input_column: Columnoutput_column: Columndepth: usizeTrait Implementations
Sourceimpl Clone for RecursionUnnestOption
impl Clone for RecursionUnnestOption
Sourcefn clone(&self) -> RecursionUnnestOption
fn clone(&self) -> RecursionUnnestOption
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecursionUnnestOption
impl Debug for RecursionUnnestOption
impl Eq for RecursionUnnestOption
Sourceimpl Hash for RecursionUnnestOption
impl Hash for RecursionUnnestOption
Sourceimpl PartialEq for RecursionUnnestOption
impl PartialEq for RecursionUnnestOption
Sourcefn eq(&self, other: &RecursionUnnestOption) -> bool
fn eq(&self, other: &RecursionUnnestOption) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RecursionUnnestOption
impl PartialOrd for RecursionUnnestOption
impl StructuralPartialEq for RecursionUnnestOption