TreeNodeRecursion

Enum TreeNodeRecursion 

pub enum TreeNodeRecursion {
    Continue,
    Jump,
    Stop,
}
Controls how TreeNode recursions should proceed.

Variants



Continue

Continue recursion with the next node.



Jump

In top-down traversals, skip recursing into children but continue with the next node, which actually means pruning of the subtree.

In bottom-up traversals, bypass calling bottom-up closures till the next leaf node.

In combined traversals, if it is the f_down (pre-order) phase, execution “jumps” to the next f_up (post-order) phase by shortcutting its children. If it is the f_up (post-order) phase, execution “jumps” to the next f_down (pre-order) phase by shortcutting its parent nodes until the first parent node having unvisited children path.



Stop

Stop recursion.

Implementations

Source

impl TreeNodeRecursion

pub fn visit_children<F: FnOnce() -> Result<TreeNodeRecursion>>( self, f: F, ) -> Result<TreeNodeRecursion>

Continues visiting nodes with f depending on the current TreeNodeRecursion value and the fact that f is visiting the current node’s children.

pub fn visit_sibling<F: FnOnce() -> Result<TreeNodeRecursion>>( self, f: F, ) -> Result<TreeNodeRecursion>

Continues visiting nodes with f depending on the current TreeNodeRecursion value and the fact that f is visiting the current node’s sibling.

pub fn visit_parent<F: FnOnce() -> Result<TreeNodeRecursion>>( self, f: F, ) -> Result<TreeNodeRecursion>

Continues visiting nodes with f depending on the current TreeNodeRecursion value and the fact that f is visiting the current node’s parent.