Module types

Module types 

Structs

DFBool8
Defines the extension type logic for the canonical arrow.bool8 extension type. This extension type allows storing a Boolean value in a single byte, instead of a single bit.
DFFixedShapeTensor
Defines the extension type logic for the canonical arrow.fixed_shape_tensor extension type. This extension type can be used to store a tensor of a fixed shape.
DFJson
Defines the extension type logic for the canonical arrow.json extension type. This extension type defines that a particular string field stores JSON values.
DFOpaque
Defines the extension type logic for the canonical arrow.opaque extension type. This extension type represents types that DataFusion cannot interpret.
DFTimestampWithOffset
Defines the extension type logic for the canonical arrow.timestamp_with_offset extension type. This extension type allows associating a different offset for each timestamp in a column.
DFUuid
Defines the extension type logic for the canonical arrow.uuid extension type. This extension type defines that a field should be interpreted as a UUID.
DFVariableShapeTensor
Defines the extension type logic for the canonical arrow.variable_shape_tensor extension type. This extension type can be used to store a tensor with variable shape that can change for each element.
LogicalField
A record of a logical type, its name and its nullability.
LogicalFields
A cheaply cloneable, owned collection of LogicalFieldRef.
LogicalUnionFields
A cheaply cloneable, owned collection of LogicalFieldRef and their corresponding type ids.

Enums

NativeType
Representation of a type that DataFusion can handle natively. It is a subset of the physical variants in Arrow’s native DataType.
TypeParameter
TypeSignature
Signature that uniquely identifies a type among other types.

Traits

DFExtensionType
Represents an implementation of a DataFusion extension type, including the storage DataType. While, in general, an extension type can support several different storage types, a specific instance of it is always locked into just one exact storage type and metadata pairing.
LogicalType
Representation of a logical type with its signature and its native backing type.

Functions

logical_binary
Getter for singleton instance of a logical type representing NativeType::Binary.
logical_boolean
Getter for singleton instance of a logical type representing NativeType::Boolean.
logical_date
Getter for singleton instance of a logical type representing NativeType::Date.
logical_duration_microsecond
Getter for singleton instance of a logical type representing NativeType::Duration of unit Microsecond.`
logical_float16
Getter for singleton instance of a logical type representing NativeType::Float16.
logical_float32
Getter for singleton instance of a logical type representing NativeType::Float32.
logical_float64
Getter for singleton instance of a logical type representing NativeType::Float64.
logical_int8
Getter for singleton instance of a logical type representing NativeType::Int8.
logical_int16
Getter for singleton instance of a logical type representing NativeType::Int16.
logical_int32
Getter for singleton instance of a logical type representing NativeType::Int32.
logical_int64
Getter for singleton instance of a logical type representing NativeType::Int64.
logical_interval_mdn
Getter for singleton instance of a logical type representing NativeType::Interval of unit MonthDayNano.`
logical_interval_year_month
Getter for singleton instance of a logical type representing NativeType::Interval of unit YearMonth.`
logical_null
Getter for singleton instance of a logical type representing NativeType::Null.
logical_string
Getter for singleton instance of a logical type representing NativeType::String.
logical_uint8
Getter for singleton instance of a logical type representing NativeType::UInt8.
logical_uint16
Getter for singleton instance of a logical type representing NativeType::UInt16.
logical_uint32
Getter for singleton instance of a logical type representing NativeType::UInt32.
logical_uint64
Getter for singleton instance of a logical type representing NativeType::UInt64.

Type Aliases

DFExtensionTypeRef
A cheaply cloneable pointer to a DFExtensionType.
LogicalFieldRef
A reference counted LogicalField.
LogicalTypeRef
A reference counted LogicalType.