pub struct DFBool8(/* private fields */);Expand description
Defines the extension type logic for the canonical arrow.bool8 extension type. This extension
type allows storing a Boolean value in a single byte, instead of a single bit.
See DFExtensionType for information on DataFusion’s extension type mechanism. See also
Bool8 for the implementation of arrow-rs, which this type uses internally.
https://arrow.apache.org/docs/format/CanonicalExtensions.html#bit-boolean
Implementations
Sourceimpl DFBool8
impl DFBool8
Sourcepub fn try_new(
data_type: &DataType,
metadata: <Bool8 as ExtensionType>::Metadata,
) -> Result<Self>
pub fn try_new( data_type: &DataType, metadata: <Bool8 as ExtensionType>::Metadata, ) -> Result<Self>
Creates a new DFBool8, validating that the storage type is compatible with the
extension type.
Even though DFBool8 only supports a single storage type (DataType::Int8), passing-in
the storage type allows conveniently validating whether this extension type is compatible
with a given DataType.