pub struct DFJson { /* private fields */ }Expand description
Defines the extension type logic for the canonical arrow.json extension type. This extension
type defines that a particular string field stores JSON values.
See DFExtensionType for information on DataFusion’s extension type mechanism. See also
Json for the implementation of arrow-rs, which this type uses internally.
https://arrow.apache.org/docs/format/CanonicalExtensions.html#json
Implementations