DFOpaque

Struct DFOpaque 

pub struct DFOpaque { /* private fields */ }
Defines the extension type logic for the canonical arrow.opaque extension type. This extension type represents types that DataFusion cannot interpret.

See DFExtensionType for information on DataFusion’s extension type mechanism. See also Opaque for the implementation of arrow-rs, which this type uses internally.

https://arrow.apache.org/docs/format/CanonicalExtensions.html#opaque

Implementations

Source

impl DFOpaque

pub fn try_new( data_type: &DataType, metadata: <Opaque as ExtensionType>::Metadata, ) -> Result<Self>

Creates a new DFOpaque, validating that the storage type is compatible with the extension type.