pub struct DFUuid(/* private fields */);Expand description
Defines the extension type logic for the canonical arrow.uuid extension type. This extension
type defines that a field should be interpreted as a
UUID.
See DFExtensionType for information on DataFusion’s extension type mechanism. See also
Uuid for the implementation of arrow-rs, which this type uses internally.
https://arrow.apache.org/docs/format/CanonicalExtensions.html#uuid
Implementations