pub struct DFVariableShapeTensor { /* private fields */ }Expand description
Defines the extension type logic for the canonical arrow.variable_shape_tensor extension type.
This extension type can be used to store a tensor with
variable shape that can change for each element.
See DFExtensionType for information on DataFusion’s extension type mechanism. See also
VariableShapeTensor for the implementation of arrow-rs, which this type uses internally.
https://arrow.apache.org/docs/format/CanonicalExtensions.html#variable-shape-tensor
Implementations
Sourceimpl DFVariableShapeTensor
impl DFVariableShapeTensor
Sourcepub fn try_new(
data_type: &DataType,
metadata: <VariableShapeTensor as ExtensionType>::Metadata,
) -> Result<Self>
pub fn try_new( data_type: &DataType, metadata: <VariableShapeTensor as ExtensionType>::Metadata, ) -> Result<Self>
Creates a new DFVariableShapeTensor, validating that the storage type is compatible with
the extension type.