list_values

Function list_values 

pub fn list_values(array: &dyn Array) -> Result<ArrayRef>
Returns the inner values of a list, or an error otherwise For ListArray and LargeListArray, if it’s sliced, it returns a sliced array too. Therefore, too reconstruct a list using it, you must adjust the offsets using adjust_offsets_for_slice