ToHex

Trait ToHex 

pub trait ToHex: ArrowNativeType {
    // Required method
    fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8] ;
}
Trait for converting integer types to hexadecimal in a buffer

Required Methods

fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8]

Writes the hex representation into buf and returns the written subslice. Digits are right-aligned with leading zeros trimmed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToHex for i8

Source

fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8]

Source

impl ToHex for i16

Source

fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8]

Source

impl ToHex for i32

Source

fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8]

Source

impl ToHex for i64

Source

fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8]

Source

impl ToHex for u8

Source

fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8]

Source

impl ToHex for u16

Source

fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8]

Source

impl ToHex for u32

Source

fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8]

Source

impl ToHex for u64

Source

fn write_hex(self, case: HexCase, buf: &mut [u8; 16]) -> &[u8]

Implementors