Module memory

Module memory 

This module provides a function to estimate the memory size of a HashTable prior to allocation

Structs

RecordBatchMemoryCounter
Tracks the memory used by a sequence of RecordBatches that may share underlying buffers, counting each buffer exactly once.

Functions

estimate_memory_size
Estimates the memory size required for a hash table prior to allocation.
get_record_batch_memory_size
Calculate total used memory of this batch.