pub struct ExplainOptions {
pub logical_plan_only: bool,
pub physical_plan_only: bool,
pub show_statistics: bool,
pub show_sizes: bool,
pub show_schema: bool,
pub format: ExplainFormat,
pub tree_maximum_render_width: usize,
pub analyze_level: MetricType,
pub analyze_categories: ExplainAnalyzeCategories,
}Expand description
Options controlling explain output
See also: SessionConfig
Fields
logical_plan_only: boolWhen set to true, the explain statement will only print logical plans
physical_plan_only: boolWhen set to true, the explain statement will only print physical plans
show_statistics: boolWhen set to true, the explain statement will print operator statistics for physical plans
show_sizes: boolWhen set to true, the explain statement will print the partition sizes
show_schema: boolWhen set to true, the explain statement will print schema information
format: ExplainFormatDisplay format of explain. Default is “indent”. When set to “tree”, it will print the plan in a tree-rendered format.
tree_maximum_render_width: usize(format=tree only) Maximum total width of the rendered tree. When set to 0, the tree will have no width limit.
analyze_level: MetricTypeVerbosity level for “EXPLAIN ANALYZE”. Default is “dev” “summary” shows common metrics for high-level insights. “dev” provides deep operator-level introspection for developers.
analyze_categories: ExplainAnalyzeCategoriesWhich metric categories to include in “EXPLAIN ANALYZE” output. Comma-separated list of: “rows”, “bytes”, “timing”, “uncategorized”. Use “none” to show plan structure only, or “all” (default) to show everything. Metrics without a declared category are treated as “uncategorized”.