A type-keyed map of opaque, Arc’d objects.
Used as the backing store for the various extensions fields throughout
DataFusion (e.g. SessionConfig, ExtendedStatistics,
PartitionedFile) so that independent components can each attach
their own data without conflict, each keyed by its concrete Rust type.
Structs
- Extensions
- A type-keyed map of opaque
Arc’d values. Each Rust typeToccupies its own slot, so independent components can each attach their own data without conflict.