pub fn validate_range_split_points(
split_points: &[SplitPoint],
sort_options: &[SortOptions],
) -> Result<()>Expand description
Validates that split points match the ordering width and are strictly ordered according to the provided sort options.