Skip to main contentModule hash_map
Source - Entry
- A view into a single entry in a map, which may either be vacant or occupied.
- EntryRef
- A view into a single entry in a map, which may either be vacant or occupied,
with any borrowed form of the map’s key type.