Functionality used both on logical and physical plans
Constants
- HLL_
RANDOM_ STATE - Fixed quality hash state used by HyperLogLog sketches.
Traits
- AsDyn
Array - Something that can be returned as a
&dyn Array. - Hash
State - Hash state used by
create_hashes. - Hash
Value
Functions
- combine_
hashes - create_
hashes - Creates hash values for every row, based on the values in the columns.
- create_
hashes_ with_ hasher - Creates hash values for every row using a caller-provided hash builder.
- with_
hashes - Creates hashes for the given arrays using a thread-local buffer, then calls the provided callback with an immutable reference to the computed hashes.
- with_
hashes_ with_ hasher - Creates hashes for the given arrays using a thread-local buffer and a custom hash builder, then calls the provided callback with the computed hashes.
Type Aliases
- Quality
Random State - Random
State RandomStateis optimized for speed and suitable for hash tables and bloom filters.QualityRandomStateis optimized for statistical quality and suitable for algorithms such as HyperLogLog. The tradeoff is that the fast variant gives up some statistical quality, while the quality variant is slightly slower.