pub trait DFHeapSize {
// Required method
fn heap_size(&self, ctx: &mut DFHeapSizeCtx) -> usize;
}Expand description
This is a temporary solution until https://github.com/apache/datafusion/pull/19599 and https://github.com/apache/arrow-rs/pull/9138 are resolved. Trait for calculating the size of various containers
Required Methods
Sourcefn heap_size(&self, ctx: &mut DFHeapSizeCtx) -> usize
fn heap_size(&self, ctx: &mut DFHeapSizeCtx) -> usize
Return the size of any bytes allocated on the heap by this object, including heap memory in those structures
Note that the size of the type itself is not included in the result – instead, that size is added by the caller (e.g. container).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".