pub struct SplitPoint { /* private fields */ }Expand description
A boundary between adjacent range partitions.
A split point is a tuple with one ScalarValue per partitioning
expression. Split points are interpreted lexicographically according to the
ordering of the range partitioning that owns them.
N split points define N + 1 partitions:
partition 0: key < split_points[0]
partition 1: split_points[0] <= key < split_points[1]
...
partition N - 1: split_points[N - 2] <= key < split_points[N - 1]
partition N: split_points[N - 1] <= keyValues equal to split point i belong to partition i + 1, so interior
partitions are lower-inclusive and upper-exclusive.
Implementations
Sourceimpl SplitPoint
impl SplitPoint
Sourcepub fn new(values: Vec<ScalarValue>) -> Self
pub fn new(values: Vec<ScalarValue>) -> Self
Creates a new split point from its tuple values.
Sourcepub fn values(&self) -> &[ScalarValue]
pub fn values(&self) -> &[ScalarValue]
Returns the tuple values for this split point.