Structs
- DFBool8
- Defines the extension type logic for the canonical
arrow.bool8extension type. This extension type allows storing a Boolean value in a single byte, instead of a single bit. - DFFixed
Shape Tensor - Defines the extension type logic for the canonical
arrow.fixed_shape_tensorextension type. This extension type can be used to store a tensor of a fixed shape. - DFJson
- Defines the extension type logic for the canonical
arrow.jsonextension type. This extension type defines that a particular string field stores JSON values. - DFOpaque
- Defines the extension type logic for the canonical
arrow.opaqueextension type. This extension type represents types that DataFusion cannot interpret. - DFTimestamp
With Offset - Defines the extension type logic for the canonical
arrow.timestamp_with_offsetextension type. This extension type allows associating a different offset for each timestamp in a column. - DFUuid
- Defines the extension type logic for the canonical
arrow.uuidextension type. This extension type defines that a field should be interpreted as a UUID. - DFVariable
Shape Tensor - Defines the extension type logic for the canonical
arrow.variable_shape_tensorextension type. This extension type can be used to store a tensor with variable shape that can change for each element. - Logical
Field - A record of a logical type, its name and its nullability.
- Logical
Fields - A cheaply cloneable, owned collection of
LogicalFieldRef. - Logical
Union Fields - A cheaply cloneable, owned collection of
LogicalFieldRefand their corresponding type ids.
Enums
- Native
Type - Representation of a type that DataFusion can handle natively. It is a subset
of the physical variants in Arrow’s native
DataType. - Type
Parameter - Type
Signature - Signature that uniquely identifies a type among other types.
Traits
- DFExtension
Type - Represents an implementation of a DataFusion extension type, including the storage
DataType. While, in general, an extension type can support several different storage types, a specific instance of it is always locked into just one exact storage type and metadata pairing. - Logical
Type - Representation of a logical type with its signature and its native backing type.
Functions
- logical_
binary - Getter for singleton instance of a logical type representing
NativeType::Binary. - logical_
boolean - Getter for singleton instance of a logical type representing
NativeType::Boolean. - logical_
date - Getter for singleton instance of a logical type representing
NativeType::Date. - logical_
duration_ microsecond - Getter for singleton instance of a logical type representing
NativeType::Durationof unitMicrosecond.` - logical_
float16 - Getter for singleton instance of a logical type representing
NativeType::Float16. - logical_
float32 - Getter for singleton instance of a logical type representing
NativeType::Float32. - logical_
float64 - Getter for singleton instance of a logical type representing
NativeType::Float64. - logical_
int8 - Getter for singleton instance of a logical type representing
NativeType::Int8. - logical_
int16 - Getter for singleton instance of a logical type representing
NativeType::Int16. - logical_
int32 - Getter for singleton instance of a logical type representing
NativeType::Int32. - logical_
int64 - Getter for singleton instance of a logical type representing
NativeType::Int64. - logical_
interval_ mdn - Getter for singleton instance of a logical type representing
NativeType::Intervalof unitMonthDayNano.` - logical_
interval_ year_ month - Getter for singleton instance of a logical type representing
NativeType::Intervalof unitYearMonth.` - logical_
null - Getter for singleton instance of a logical type representing
NativeType::Null. - logical_
string - Getter for singleton instance of a logical type representing
NativeType::String. - logical_
uint8 - Getter for singleton instance of a logical type representing
NativeType::UInt8. - logical_
uint16 - Getter for singleton instance of a logical type representing
NativeType::UInt16. - logical_
uint32 - Getter for singleton instance of a logical type representing
NativeType::UInt32. - logical_
uint64 - Getter for singleton instance of a logical type representing
NativeType::UInt64.
Type Aliases
- DFExtension
Type Ref - A cheaply cloneable pointer to a
DFExtensionType. - Logical
Field Ref - A reference counted
LogicalField. - Logical
Type Ref - A reference counted
LogicalType.