pub struct DFFixedShapeTensor { /* private fields */ }Expand description
Defines the extension type logic for the canonical arrow.fixed_shape_tensor extension type.
This extension type can be used to store a tensor of
a fixed shape.
See DFExtensionType for information on DataFusion’s extension type mechanism. See also
FixedShapeTensor for the implementation of arrow-rs, which this type uses internally.
https://arrow.apache.org/docs/format/CanonicalExtensions.html#fixed-shape-tensor
Implementations
Sourceimpl DFFixedShapeTensor
impl DFFixedShapeTensor
Sourcepub fn try_new(
data_type: &DataType,
metadata: <FixedShapeTensor as ExtensionType>::Metadata,
) -> Result<Self>
pub fn try_new( data_type: &DataType, metadata: <FixedShapeTensor as ExtensionType>::Metadata, ) -> Result<Self>
Creates a new DFFixedShapeTensor, validating that the storage type is compatible with
the extension type.