pub fn adjust_offsets_for_slice<O: OffsetSizeTrait>(
list: &GenericListArray<O>,
) -> OffsetBuffer<O>Expand description
If list is sliced, returns an adjusted offset buffer so that
it points to the sliced portion of the list values, and not the whole list values