This module provides a function to estimate the memory size of a HashTable prior to allocation
Structs
- Record
Batch Memory Counter - Tracks the memory used by a sequence of
RecordBatches that may share underlying buffers, counting each buffer exactly once.
Functions
- estimate_
memory_ size - Estimates the memory size required for a hash table prior to allocation.
- get_
record_ batch_ memory_ size - Calculate total used memory of this batch.